From cc685f1c24eca300a511ca5676a7505916b4b356 Mon Sep 17 00:00:00 2001
From: Yann Leboulanger <asterix@lagaule.org>
Date: Tue, 4 Nov 2008 10:45:48 +0000
Subject: [PATCH] request jabber:iq:last only when contact is offline. Fixes
 #4434

---
 src/vcard.py | 17 +++++++++--------
 1 file changed, 9 insertions(+), 8 deletions(-)

diff --git a/src/vcard.py b/src/vcard.py
index 0685976bfe..8febe9163e 100644
--- a/src/vcard.py
+++ b/src/vcard.py
@@ -342,14 +342,15 @@ class VcardWindow:
 		if not self.contact.status:
 			self.contact.status = ''
 
-		# Request list time status
-		if self.gc_contact:
-			j, r = gajim.get_room_and_nick_from_fjid(self.real_jid)
-			gajim.connections[self.account].request_last_status_time(j, r,
-				self.contact.jid)
-		else:
-			gajim.connections[self.account].request_last_status_time(
-				self.contact.jid, self.contact.resource)
+		# Request list time status only if contact is offline
+		if self.contact.show == 'offline':
+			if self.gc_contact:
+				j, r = gajim.get_room_and_nick_from_fjid(self.real_jid)
+				gajim.connections[self.account].request_last_status_time(j, r,
+					self.contact.jid)
+			else:
+				gajim.connections[self.account].request_last_status_time(
+					self.contact.jid, self.contact.resource)
 
 		# do not wait for os_info if contact is not connected or has error
 		# additional check for observer is needed, as show is offline for him
-- 
GitLab